%% Convert images to grayscale
ref_img = 0.2989*ref_img_clr(:,:,1)+0.5870*ref_img_clr(:,:,2)+0.1140*ref_img_clr(:,:,3); 
% plotImage(ref_img)

%% Binarize the image

% create binary image
ref_img_bw = im2bw(ref_img, D(1).binarizationLimit);
% % plotImage(ref_img_bw)

%% get blob areas
ref_img_bw = ExtractNLargestBlobs(ref_img_bw,1);
% plotImage(ref_img_bw)

ref_img_wb = ~ref_img_bw;
ref_img_wb = ExtractNLargestBlobs(ref_img_wb,1);

% plotImage(ref_img_wb)

%% create clean distinct areas
for i = 1:size(ref_img_bw,1)
    for j = 1:size(ref_img_bw,2)
        if ~ref_img_bw(i,j) && ref_img_wb(i,j)
            ref_img(i,j) = true;
        else
            ref_img(i,j) = false;
        end
    end
end

ref_img = logical(ref_img');
% plotImage(ref_img)

%% smooth edges
ref_img_smoothed = bwmorph(ref_img, 'erode', D(1).smoothingRadius);
% plotImage(ref_img_smoothed)

%% create contour lines

% droplet / surface level is true at this moment

for i = 1:size(ref_img,2)
    trueRows = find(ref_img_smoothed(:,i));
    if ~isempty(trueRows)
        peakOfDrop = [round(mean(trueRows)),i];  
        break
    end
end

cL_1x = zeros(1,size(ref_img,2)-peakOfDrop(2));
cL_1y = zeros(1,size(ref_img,2)-peakOfDrop(2));
cL_2x = zeros(1,size(ref_img,2)-peakOfDrop(2));
cL_2y = zeros(1,size(ref_img,2)-peakOfDrop(2));

counter = 0;
lastJ = 0;
for j = peakOfDrop(2)+round((size(ref_img,2)-peakOfDrop(2))/8):size(ref_img,2)
    for i = peakOfDrop(1):-1:1
        if ~ref_img_smoothed(i,j)
            counter = counter+1;
            if counter > 1
                if abs(cL_1x(counter-1)-i) > D(1).derivativeLimit
                    lastJ = counter-1;
                    break
                end
            end
            cL_1y(counter) = j;
            cL_1x(counter) = i;
            break
        end
    end
    if lastJ > 0
        break
    end
end
cL_1x = cL_1x(1:lastJ);
cL_1y = cL_1y(1:lastJ);

counter = 0;
lastJ = 0;
for j = peakOfDrop(2)+round((size(ref_img,2)-peakOfDrop(2))/8):size(ref_img,2)
    for i = peakOfDrop(1):size(ref_img,1)
        if ~ref_img_smoothed(i,j)
            counter = counter+1;
            if counter > 1
                if abs(cL_2x(counter-1)-i) > D(1).derivativeLimit
                    lastJ = counter-1;
                    break
                end
            end
            cL_2y(counter) = j;
            cL_2x(counter) = i;
            break
        end
    end
    if lastJ > 0
        break
    end
end
cL_2x = cL_2x(1:lastJ);
cL_2y = cL_2y(1:lastJ);

% figure
% imshow(ref_img_smoothed')
% hold on
% plot(cL_1x, cL_1y,'-r','LineWidth',2)
% plot(cL_2x, cL_2y,'-b','LineWidth',2)

%% find fiber-liquid level boundary

P1 = [cL_1x(end-10*D(1).xOffset), cL_1y(end-10*D(1).xOffset)];
P2 = [cL_2x(end-10*D(1).xOffset), cL_2y(end-10*D(1).xOffset)];

dy_dx_1 = 2*D(1).dx/(cL_1x(end-10*D(1).xOffset-2*D(1).dx)-cL_1x(end-10*D(1).xOffset));
dy_dx_2 = 2*D(1).dx/(cL_2x(end-10*D(1).xOffset)-cL_2x(end-10*D(1).xOffset-2*D(1).dx));

slope_1 = atand(dy_dx_1);
slope_2 = atand(dy_dx_2);

%% plotting data
radius = 1.7*length(cL_1y);

sl_1 = atand(dy_dx_1);
sl_2 = atand(dy_dx_2);

x1 = [P1(1)+radius*cosd(-sl_1), P1(1)-radius*cosd(-sl_1)];
x2 = [P2(1)+radius*cosd(sl_2), P2(1)-radius*cosd(sl_2)];

y1 = [P1(2)+radius*sind(-sl_1), P1(2)-radius*sind(-sl_1)];
y2 = [P2(2)+radius*sind(sl_2), P2(2)-radius*sind(sl_2)];

%% save the results
D(processedImage).P1 = P1;
D(processedImage).P2 = P2;
D(processedImage).slope_1 = slope_1;
D(processedImage).slope_2 = slope_2;
D(processedImage).x1 = x1;
D(processedImage).y1 = y1;
D(processedImage).x2 = x2;
D(processedImage).y2 = y2;
D(processedImage).radius = radius;

